;;; DO NOT MODIFY THIS FILE
(if (featurep 'general-docs-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "general-docs/_pkg.el")

(package-provide 'general-docs :version 1.01 :author-version "No-Upstream-Ver" :type 'regular)

;;;***

(provide 'general-docs-autoloads)
